# Matrix Guide

```{toctree}
:numbered:
:maxdepth: 2

matrix/matrix-basics
matrix/matrix-generate
matrix/matrix-calculating quantities
matrix/matrix-solving systems
matrix/matrix-distributed parallelism - mpi
matrix/matrix-dynamics and evolution
```